@@ -599,6 +599,7 @@ class Witter():
                 f5.write("senderName" + str(counter) + " = " + store.get_value(item,0)+"\n")
                 f5.write("senderId" + str(counter) + " = " +store.get_value(item,1)+"\n")
                 tweet = store.get_value(item,2)
+                tweet = tweet.replace(";","&SC;")
                 tweet = tweet.replace("\n","&CR;")
                 f5.write("tweet" + str(counter) + " = " +tweet+"\n")
                 #3 is unused now, used to be tweet colour
@@ -632,6 +633,7 @@ class Witter():
                 senderId = config.get("tweets", "senderId" + str(counter));
                 tweet = config.get("tweets", "tweet" + str(counter));
                 tweet = tweet.replace("&CR;","\n")
+                tweet = tweet.replace("&SC;",";")
                 tweetId = config.get("tweets", "tweetId" + str(counter));
                 tweet_long_id = float(tweetId)
                 createdAt = config.get("tweets", "createdAt" + str(counter));
